@@ -111,6 +111,9 @@ class Message:
         if 'query' in dictionary:
             self.has_query = True
             self.query = dictionary['query']
+            self.query_since = dictionary['since-ex']['query'] if 'since-ex' in dictionary else dictionary['since'] if 'since' in dictionary else None
+            if self.query_since is None:
+                raise ValueError('Message ' + self.name + ' (query) requires a "since" tag specifying the major version where it was introduced')
             validate_fields(self.query)
         else:
             self.has_query = False
@@ -120,6 +123,9 @@ class Message:
         if 'set' in dictionary:
             self.has_set = True
             self.set = dictionary['set']
+            self.set_since = dictionary['since-ex']['set'] if 'since-ex' in dictionary else dictionary['since'] if 'since' in dictionary else None
+            if self.set_since is None:
+                raise ValueError('Message ' + self.name + ' (set) requires a "since" tag specifying the major version where it was introduced')
             validate_fields(self.set)
         else:
             self.has_set = False
@@ -130,6 +136,9 @@ class Message:
         if 'response' in dictionary:
             self.has_response = True
             self.response = dictionary['response']
+            self.response_since = dictionary['since-ex']['response'] if 'since-ex' in dictionary else dictionary['since'] if 'since' in dictionary else None
+            if self.response_since is None:
+                raise ValueError('Message ' + self.name + ' (response) requires a "since" tag specifying the major version where it was introduced')
             validate_fields(self.response)
         else:
             self.has_response = False
@@ -139,6 +148,9 @@ class Message:
         if 'notification' in dictionary:
             self.has_notification = True
             self.notification = dictionary['notification']
+            self.notification_since = dictionary['since-ex']['notification'] if 'since-ex' in dictionary else dictionary['since'] if 'since' in dictionary else None
+            if self.notification_since is None:
+                raise ValueError('Message ' + self.name + ' (notification) requires a "since" tag specifying the major version where it was introduced')
             validate_fields(self.notification)
         else:
             self.has_notification = False
@@ -166,41 +178,101 @@ class Message:
         if self.has_query:
             utils.add_separator(hfile, 'Message (Query)', self.fullname);
             utils.add_separator(cfile, 'Message (Query)', self.fullname);
-            self._emit_message_creator(hfile, cfile, 'query', self.query)
+            self._emit_message_creator(hfile, cfile, 'query', self.query, self.query_since)
             self._emit_message_printable(cfile, 'query', self.query)
 
         if self.has_set:
             utils.add_separator(hfile, 'Message (Set)', self.fullname);
             utils.add_separator(cfile, 'Message (Set)', self.fullname);
-            self._emit_message_creator(hfile, cfile, 'set', self.set)
+            self._emit_message_creator(hfile, cfile, 'set', self.set, self.set_since)
             self._emit_message_printable(cfile, 'set', self.set)
 
         if self.has_response:
             utils.add_separator(hfile, 'Message (Response)', self.fullname);
             utils.add_separator(cfile, 'Message (Response)', self.fullname);
-            self._emit_message_parser(hfile, cfile, 'response', self.response)
+            self._emit_message_parser(hfile, cfile, 'response', self.response, self.response_since)
             self._emit_message_printable(cfile, 'response', self.response)
 
         if self.has_notification:
             utils.add_separator(hfile, 'Message (Notification)', self.fullname);
             utils.add_separator(cfile, 'Message (Notification)', self.fullname);
-            self._emit_message_parser(hfile, cfile, 'notification', self.notification)
+            self._emit_message_parser(hfile, cfile, 'notification', self.notification, self.notification_since)
             self._emit_message_printable(cfile, 'notification', self.notification)
 
 
     """
     Emit message creator
     """
-    def _emit_message_creator(self, hfile, cfile, message_type, fields):
+    def _emit_message_creator(self, hfile, cfile, message_type, fields, since):
         translations = { 'message'                  : self.name,
                          'service'                  : self.service,
+                         'since'                    : since,
                          'underscore'               : utils.build_underscore_name (self.fullname),
                          'message_type'             : message_type,
                          'message_type_upper'       : message_type.upper(),
                          'service_underscore_upper' : utils.build_underscore_name (self.service).upper(),
                          'cid_enum_name'            : self.cid_enum_name }
+
         template = (
             '\n'
+            '/**\n'
+            ' * ${underscore}_${message_type}_new:\n')
+
+        for field in fields:
+            translations['name'] = field['name']
+            translations['field'] = utils.build_underscore_name_from_camelcase (field['name'])
+            translations['struct'] = field['struct-type'] if 'struct-type' in field else ''
+            translations['public'] = field['public-format'] if 'public-format' in field else field['format']
+            translations['array_size'] = field['array-size'] if 'array-size' in field else ''
+
+            inner_template = ''
+            if field['format'] == 'byte-array':
+                inner_template = (' * @${field}: (in)(element-type guint8)(array fixed-size=${array_size}): the \'${name}\' field, given as an array of ${array_size} #guint8 values.\n')
+            elif field['format'] == 'unsized-byte-array' or \
+                 field['format'] == 'ref-byte-array' or \
+                 field['format'] == 'ref-byte-array-no-offset':
+                inner_template = (' * @${field}_size: (in): size of the ${field} array.\n'
+                                  ' * @${field}: (in)(element-type guint8)(array length=${field}_size): the \'${name}\' field, given as an array of #guint8 values.\n')
+            elif field['format'] == 'uuid':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #MbimUuid.\n')
+            elif field['format'] == 'guint32':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #${public}.\n')
+            elif field['format'] == 'guint64':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #${public}.\n')
+            elif field['format'] == 'string':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a string.\n')
+            elif field['format'] == 'string-array':
+                inner_template = (' * @${field}: (in)(type GStrv): the \'${name}\' field, given as an array of strings.\n')
+            elif field['format'] == 'struct':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #${struct}.\n')
+            elif field['format'] == 'struct-array':
+                inner_template = (' * @${field}: (in)(array zero-terminated=1)(element-type ${struct}): the \'${name}\' field, given as an array of #${struct}s.\n')
+            elif field['format'] == 'ref-struct-array':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as an array of #${struct}s.\n')
+            elif field['format'] == 'ipv4':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #MbimIPv4.\n')
+            elif field['format'] == 'ref-ipv4':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #MbimIPv4.\n')
+            elif field['format'] == 'ipv4-array':
+                inner_template = (' * @${field}: (in)(array zero-terminated=1)(element-type MbimIPv4): the \'${name}\' field, given as an array of #MbimIPv4.\n')
+            elif field['format'] == 'ipv6':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #MbimIPv6.\n')
+            elif field['format'] == 'ref-ipv6':
+                inner_template = (' * @${field}: (in): the \'${name}\' field, given as a #MbimIPv6.\n')
+            elif field['format'] == 'ipv6-array':
+                inner_template = (' * @${field}: (in)(array zero-terminated=1)(element-type MbimIPv6): the \'${name}\' field, given as an array of #MbimIPv6.\n')
+
+            template += (string.Template(inner_template).substitute(translations))
+
+        template += (
+            ' * @error: return location for error or %NULL.\n'
+            ' *\n'
+            ' * Create a new request for the \'${message}\' ${message_type} command in the \'${service}\' service.\n'
+            ' *\n'
+            ' * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().\n'
+            ' *\n'
+            ' * Since: ${since}\n'
+            ' */\n'
             'MbimMessage *${underscore}_${message_type}_new (\n')
 
         for field in fields:
@@ -253,62 +325,6 @@ class Message:
 
         template = (
             '\n'
-            '/**\n'
-            ' * ${underscore}_${message_type}_new:\n')
-
-        for field in fields:
-            translations['name'] = field['name']
-            translations['field'] = utils.build_underscore_name_from_camelcase (field['name'])
-            translations['struct'] = field['struct-type'] if 'struct-type' in field else ''
-            translations['public'] = field['public-format'] if 'public-format' in field else field['format']
-            translations['array_size'] = field['array-size'] if 'array-size' in field else ''
-
-            inner_template = ''
-            if field['format'] == 'byte-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of ${array_size} #guint8 values.\n')
-            elif field['format'] == 'unsized-byte-array' or \
-                 field['format'] == 'ref-byte-array' or \
-                 field['format'] == 'ref-byte-array-no-offset':
-                inner_template = (' * @${field}_size: size of the ${field} array.\n'
-                                  ' * @${field}: the \'${name}\' field, given as an array of #guint8 values.\n')
-            elif field['format'] == 'uuid':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #MbimUuid.\n')
-            elif field['format'] == 'guint32':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #${public}.\n')
-            elif field['format'] == 'guint64':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #${public}.\n')
-            elif field['format'] == 'string':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a string.\n')
-            elif field['format'] == 'string-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of strings.\n')
-            elif field['format'] == 'struct':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #${struct}.\n')
-            elif field['format'] == 'struct-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of #${struct}s.\n')
-            elif field['format'] == 'ref-struct-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of #${struct}s.\n')
-            elif field['format'] == 'ipv4':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #MbimIPv4.\n')
-            elif field['format'] == 'ref-ipv4':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #MbimIPv4.\n')
-            elif field['format'] == 'ipv4-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of #MbimIPv4.\n')
-            elif field['format'] == 'ipv6':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #MbimIPv6.\n')
-            elif field['format'] == 'ref-ipv6':
-                inner_template = (' * @${field}: the \'${name}\' field, given as a #MbimIPv6.\n')
-            elif field['format'] == 'ipv6-array':
-                inner_template = (' * @${field}: the \'${name}\' field, given as an array of #MbimIPv6.\n')
-
-            template += (string.Template(inner_template).substitute(translations))
-
-        template += (
-            ' * @error: return location for error or %NULL.\n'
-            ' *\n'
-            ' * Create a new request for the \'${message}\' ${message_type} command in the \'${service}\' service.\n'
-            ' *\n'
-            ' * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().\n'
-            ' */\n'
             'MbimMessage *\n'
             '${underscore}_${message_type}_new (\n')
 
@@ -439,15 +455,75 @@ class Message:
     """
     Emit message parser
     """
-    def _emit_message_parser(self, hfile, cfile, message_type, fields):
+    def _emit_message_parser(self, hfile, cfile, message_type, fields, since):
         translations = { 'message'                  : self.name,
                          'service'                  : self.service,
+                         'since'                    : since,
                          'underscore'               : utils.build_underscore_name (self.fullname),
                          'message_type'             : message_type,
                          'message_type_upper'       : message_type.upper(),
                          'service_underscore_upper' : utils.build_underscore_name (self.service).upper() }
+
         template = (
             '\n'
+            '/**\n'
+            ' * ${underscore}_${message_type}_parse:\n'
+            ' * @message: the #MbimMessage.\n')
+
+        for field in fields:
+            translations['field'] = utils.build_underscore_name_from_camelcase(field['name'])
+            translations['name'] = field['name']
+            translations['public'] = field['public-format'] if 'public-format' in field else field['format']
+            translations['struct'] = field['struct-type'] if 'struct-type' in field else ''
+            translations['struct_underscore'] = utils.build_underscore_name_from_camelcase (translations['struct'])
+            translations['array_size'] = field['array-size'] if 'array-size' in field else ''
+
+            inner_template = ''
+            if field['format'] == 'byte-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none)(element-type guint8)(array fixed-size=${array_size}): return location for an array of ${array_size} #guint8 values. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'unsized-byte-array' or field['format'] == 'ref-byte-array':
+                inner_template = (' * @out_${field}_size: (out)(optional): return location for the size of the ${field} array.\n'
+                                  ' * @out_${field}: (out)(optional)(transfer none)(element-type guint8)(array length=out_${field}_size): return location for an array of #guint8 values. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'uuid':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #MbimUuid, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'guint32':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #${public}, or %NULL if the \'${name}\' field is not needed.\n')
+            elif field['format'] == 'guint64':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #guint64, or %NULL if the \'${name}\' field is not needed.\n')
+            elif field['format'] == 'string':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full): return location for a newly allocated string, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
+            elif field['format'] == 'string-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full)(type GStrv): return location for a newly allocated array of strings, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_strfreev().\n')
+            elif field['format'] == 'struct':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full): return location for a newly allocated #${struct}, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_free().\n')
+            elif field['format'] == 'struct-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full)(array zero-terminated=1)(element-type ${struct}): return location for a newly allocated array of #${struct}s, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_array_free().\n')
+            elif field['format'] == 'ref-struct-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full)(array zero-terminated=1)(element-type ${struct}): return location for a newly allocated array of #${struct}s, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_array_free().\n')
+            elif field['format'] == 'ipv4':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #MbimIPv4, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'ref-ipv4':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #MbimIPv4, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'ipv4-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full)(array zero-terminated=1)(element-type MbimIPv4): return location for a newly allocated array of #MbimIPv4s, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
+            elif field['format'] == 'ipv6':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #MbimIPv6, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'ref-ipv6':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer none): return location for a #MbimIPv6, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
+            elif field['format'] == 'ipv6-array':
+                inner_template = (' * @out_${field}: (out)(optional)(transfer full)(array zero-terminated=1)(element-type MbimIPv6): return location for a newly allocated array of #MbimIPv6s, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
+
+            template += (string.Template(inner_template).substitute(translations))
+
+        template += (
+            ' * @error: return location for error or %NULL.\n'
+            ' *\n'
+            ' * Parses and returns parameters of the \'${message}\' ${message_type} command in the \'${service}\' service.\n'
+            ' *\n'
+            ' * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.\n'
+            ' *\n'
+            ' * Since: ${since}\n'
+            ' */\n'
             'gboolean ${underscore}_${message_type}_parse (\n'
             '    const MbimMessage *message,\n')
 
@@ -475,9 +551,9 @@ class Message:
             elif field['format'] == 'struct':
                 inner_template = ('    ${struct} **out_${field},\n')
             elif field['format'] == 'struct-array':
-                inner_template = ('    ${struct} ***out_${field},\n')
+                inner_template = ('    ${struct}Array **out_${field},\n')
             elif field['format'] == 'ref-struct-array':
-                inner_template = ('    ${struct} ***out_${field},\n')
+                inner_template = ('    ${struct}Array **out_${field},\n')
             elif field['format'] == 'ipv4':
                 inner_template = ('    const MbimIPv4 **out_${field},\n')
             elif field['format'] == 'ref-ipv4':
@@ -501,62 +577,6 @@ class Message:
 
         template = (
             '\n'
-            '/**\n'
-            ' * ${underscore}_${message_type}_parse:\n'
-            ' * @message: the #MbimMessage.\n')
-
-        for field in fields:
-            translations['field'] = utils.build_underscore_name_from_camelcase(field['name'])
-            translations['name'] = field['name']
-            translations['public'] = field['public-format'] if 'public-format' in field else field['format']
-            translations['struct'] = field['struct-type'] if 'struct-type' in field else ''
-            translations['struct_underscore'] = utils.build_underscore_name_from_camelcase (translations['struct'])
-            translations['array_size'] = field['array-size'] if 'array-size' in field else ''
-
-            inner_template = ''
-            if field['format'] == 'byte-array':
-                inner_template = (' * @out_${field}: return location for an array of ${array_size} #guint8 values. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'unsized-byte-array' or field['format'] == 'ref-byte-array':
-                inner_template = (' * @out_${field}_size: return location for the size of the ${field} array.\n'
-                                  ' * @out_${field}: return location for an array of #guint8 values. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'uuid':
-                inner_template = (' * @out_${field}: return location for a #MbimUuid, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'guint32':
-                inner_template = (' * @out_${field}: return location for a #${public}, or %NULL if the \'${name}\' field is not needed.\n')
-            elif field['format'] == 'guint64':
-                inner_template = (' * @out_${field}: return location for a #guint64, or %NULL if the \'${name}\' field is not needed.\n')
-            elif field['format'] == 'string':
-                inner_template = (' * @out_${field}: return location for a newly allocated string, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
-            elif field['format'] == 'string-array':
-                inner_template = (' * @out_${field}: return location for a newly allocated array of strings, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_strfreev().\n')
-            elif field['format'] == 'struct':
-                inner_template = (' * @out_${field}: return location for a newly allocated #${struct}, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_free().\n')
-            elif field['format'] == 'struct-array':
-                inner_template = (' * @out_${field}: return location for a newly allocated array of #${struct}s, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_array_free().\n')
-            elif field['format'] == 'ref-struct-array':
-                inner_template = (' * @out_${field}: return location for a newly allocated array of #${struct}s, or %NULL if the \'${name}\' field is not needed. Free the returned value with ${struct_underscore}_array_free().\n')
-            elif field['format'] == 'ipv4':
-                inner_template = (' * @out_${field}: return location for a #MbimIPv4, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'ref-ipv4':
-                inner_template = (' * @out_${field}: return location for a #MbimIPv4, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'ipv4-array':
-                inner_template = (' * @out_${field}: return location for a newly allocated array of #MbimIPv4s, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
-            elif field['format'] == 'ipv6':
-                inner_template = (' * @out_${field}: return location for a #MbimIPv6, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'ref-ipv6':
-                inner_template = (' * @out_${field}: return location for a #MbimIPv6, or %NULL if the \'${name}\' field is not needed. Do not free the returned value, it is owned by @message.\n')
-            elif field['format'] == 'ipv6-array':
-                inner_template = (' * @out_${field}: return location for a newly allocated array of #MbimIPv6s, or %NULL if the \'${name}\' field is not needed. Free the returned value with g_free().\n')
-
-            template += (string.Template(inner_template).substitute(translations))
-
-        template += (
-            ' * @error: return location for error or %NULL.\n'
-            ' *\n'
-            ' * Parses and returns parameters of the \'${message}\' ${message_type} command in the \'${service}\' service.\n'
-            ' *\n'
-            ' * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.\n'
-            ' */\n'
             'gboolean\n'
             '${underscore}_${message_type}_parse (\n'
             '    const MbimMessage *message,\n')
@@ -585,9 +605,9 @@ class Message:
             elif field['format'] == 'struct':
                 inner_template = ('    ${struct} **out_${field},\n')
             elif field['format'] == 'struct-array':
-                inner_template = ('    ${struct} ***out_${field},\n')
+                inner_template = ('    ${struct}Array **out_${field},\n')
             elif field['format'] == 'ref-struct-array':
-                inner_template = ('    ${struct} ***out_${field},\n')
+                inner_template = ('    ${struct}Array **out_${field},\n')
             elif field['format'] == 'ipv4':
                 inner_template = ('    const MbimIPv4 **out_${field},\n')
             elif field['format'] == 'ref-ipv4':
@@ -1069,15 +1089,14 @@ class Message:
 
             elif field['format'] == 'uuid':
                 inner_template += (
-                    '        const MbimUuid *tmp;\n'
-                    '        gchar *tmpstr;\n'
+                    '        const MbimUuid   *tmp;\n'
+                    '        g_autofree gchar *tmpstr = NULL;\n'
                     '\n'
                     '        if (!_mbim_message_read_uuid (message, offset, &tmp, &inner_error))\n'
                     '            goto out;\n'
                     '        offset += 16;\n'
                     '        tmpstr = mbim_uuid_get_printable (tmp);\n'
-                    '        g_string_append_printf (str, "\'%s\'", tmpstr);\n'
-                    '        g_free (tmpstr);\n')
+                    '        g_string_append_printf (str, "\'%s\'", tmpstr);\n')
 
             elif field['format'] == 'guint32' or \
                  field['format'] == 'guint64':
@@ -1101,11 +1120,10 @@ class Message:
                         '        g_string_append_printf (str, "\'%s\'", ${public_underscore}_get_string ((${public})tmp));\n'
                         '#elif defined __${public_underscore_upper}_IS_FLAGS__\n'
                         '        {\n'
-                        '            gchar *tmpstr;\n'
+                        '            g_autofree gchar *tmpstr = NULL;\n'
                         '\n'
                         '            tmpstr = ${public_underscore}_build_string_from_mask ((${public})tmp);\n'
                         '            g_string_append_printf (str, "\'%s\'", tmpstr);\n'
-                        '            g_free (tmpstr);\n'
                         '        }\n'
                         '#else\n'
                         '# error neither enum nor flags\n'
@@ -1120,17 +1138,16 @@ class Message:
 
             elif field['format'] == 'string':
                 inner_template += (
-                    '        gchar *tmp;\n'
+                    '        g_autofree gchar *tmp = NULL;\n'
                     '\n'
                     '        if (!_mbim_message_read_string (message, 0, offset, &tmp, &inner_error))\n'
                     '            goto out;\n'
                     '        offset += 8;\n'
-                    '        g_string_append_printf (str, "\'%s\'", tmp);\n'
-                    '        g_free (tmp);\n')
+                    '        g_string_append_printf (str, "\'%s\'", tmp);\n')
 
             elif field['format'] == 'string-array':
                 inner_template += (
-                    '        gchar **tmp;\n'
+                    '        g_auto(GStrv) tmp = NULL;\n'
                     '        guint i;\n'
                     '\n'
                     '        if (!_mbim_message_read_string_array (message, _${array_size_field}, 0, offset, &tmp, &inner_error))\n'
@@ -1143,15 +1160,14 @@ class Message:
                     '            if (i < (_${array_size_field} - 1))\n'
                     '                g_string_append (str, ", ");\n'
                     '        }\n'
-                    '        g_string_append (str, "\'");\n'
-                    '        g_strfreev (tmp);\n')
+                    '        g_string_append (str, "\'");\n')
 
             elif field['format'] == 'struct':
                 inner_template += (
-                    '        ${struct_type} *tmp;\n'
+                    '        g_autoptr(${struct_type}) tmp = NULL;\n'
+                    '        g_autofree gchar *new_line_prefix = NULL;\n'
+                    '        g_autofree gchar *struct_str = NULL;\n'
                     '        guint32 bytes_read = 0;\n'
-                    '        gchar *new_line_prefix;\n'
-                    '        gchar *struct_str;\n'
                     '\n'
                     '        tmp = _mbim_message_read_${struct_name}_struct (message, offset, &bytes_read, &inner_error);\n'
                     '        if (!tmp)\n'
@@ -1161,15 +1177,12 @@ class Message:
                     '        new_line_prefix = g_strdup_printf ("%s    ", line_prefix);\n'
                     '        struct_str = _mbim_message_print_${struct_name}_struct (tmp, new_line_prefix);\n'
                     '        g_string_append (str, struct_str);\n'
-                    '        g_free (struct_str);\n'
-                    '        g_string_append_printf (str, "%s  }\\n", line_prefix);\n'
-                    '        g_free (new_line_prefix);\n'
-                    '        _${struct_name}_free (tmp);\n')
+                    '        g_string_append_printf (str, "%s  }\\n", line_prefix);\n')
 
             elif field['format'] == 'struct-array' or field['format'] == 'ref-struct-array':
                 inner_template += (
-                    '        ${struct_type} **tmp;\n'
-                    '        gchar *new_line_prefix;\n'
+                    '        g_autoptr(${struct_type}Array) tmp = NULL;\n'
+                    '        g_autofree gchar *new_line_prefix = NULL;\n'
                     '        guint i;\n'
                     '\n')
 
@@ -1188,17 +1201,14 @@ class Message:
                     '        new_line_prefix = g_strdup_printf ("%s        ", line_prefix);\n'
                     '        g_string_append (str, "\'{\\n");\n'
                     '        for (i = 0; i < _${array_size_field}; i++) {\n'
-                    '            gchar *struct_str;\n'
+                    '            g_autofree gchar *struct_str = NULL;\n'
                     '\n'
                     '            g_string_append_printf (str, "%s    [%u] = {\\n", line_prefix, i);\n'
                     '            struct_str = _mbim_message_print_${struct_name}_struct (tmp[i], new_line_prefix);\n'
                     '            g_string_append (str, struct_str);\n'
-                    '            g_free (struct_str);\n'
                     '            g_string_append_printf (str, "%s    },\\n", line_prefix);\n'
                     '        }\n'
-                    '        g_string_append_printf (str, "%s  }\'", line_prefix);\n'
-                    '        g_free (new_line_prefix);\n'
-                    '        ${struct_name}_array_free (tmp);\n')
+                    '        g_string_append_printf (str, "%s  }\'", line_prefix);\n')
 
             elif field['format'] == 'ipv4' or \
                  field['format'] == 'ref-ipv4' or \
@@ -1212,14 +1222,14 @@ class Message:
                         '        const MbimIPv4 *tmp;\n')
                 elif field['format'] == 'ipv4-array':
                     inner_template += (
-                        '        MbimIPv4 *tmp;\n')
+                        '        g_autofree MbimIPv4 *tmp = NULL;\n')
                 elif field['format'] == 'ipv6' or \
                      field['format'] == 'ref-ipv6':
                     inner_template += (
                         '        const MbimIPv6 *tmp;\n')
                 elif field['format'] == 'ipv6-array':
                     inner_template += (
-                        '        MbimIPv6 *tmp;\n')
+                        '        g_autofree MbimIPv6 *tmp = NULL;\n')
 
                 inner_template += (
                     '        guint array_size;\n'
@@ -1267,8 +1277,8 @@ class Message:
                     '        g_string_append (str, "\'");\n'
                     '        if (tmp) {\n'
                     '            for (i = 0; i < array_size; i++) {\n'
-                    '                GInetAddress *addr;\n'
-                    '                gchar *tmpstr;\n'
+                    '                g_autoptr(GInetAddress)  addr = NULL;\n'
+                    '                g_autofree gchar        *tmpstr = NULL;\n'
                     '\n')
 
                 if field['format'] == 'ipv4' or \
@@ -1285,19 +1295,12 @@ class Message:
                 inner_template += (
                     '                tmpstr = g_inet_address_to_string (addr);\n'
                     '                g_string_append_printf (str, "%s", tmpstr);\n'
-                    '                g_free (tmpstr);\n'
-                    '                g_object_unref (addr);\n'
                     '                if (i < (array_size - 1))\n'
                     '                    g_string_append (str, ", ");\n'
                     '            }\n'
                     '        }\n'
                     '        g_string_append (str, "\'");\n')
 
-                if field['format'] == 'ipv4-array' or \
-                   field['format'] == 'ipv6-array':
-                    inner_template += (
-                        '        g_free (tmp);\n')
-
             else:
                 raise ValueError('Field format \'%s\' not printable' % field['format'])
 
