@@ -158,8 +158,11 @@ transaction_context_free (TransactionContext *ctx)
     if (ctx->fragments)
         mbim_message_unref (ctx->fragments);
 
-    if (ctx->timeout_source)
-        g_source_destroy (ctx->timeout_source);
+    if (ctx->timeout_source) {
+        if (!g_source_is_destroyed (ctx->timeout_source))
+            g_source_destroy (ctx->timeout_source);
+        g_source_unref (ctx->timeout_source);
+    }
 
     if (ctx->cancellable) {
         if (ctx->cancellable_id)
@@ -369,7 +372,6 @@ device_store_transaction (MbimDevice       *self,
         ctx->timeout_source = g_timeout_source_new (timeout_ms);
         g_source_set_callback (ctx->timeout_source, (GSourceFunc)transaction_timed_out, ctx->wait_ctx, NULL);
         g_source_attach (ctx->timeout_source, g_main_context_get_thread_default ());
-        g_source_unref (ctx->timeout_source);
     }
 
     /* Indication transactions don't have cancellable */
@@ -868,8 +870,9 @@ get_descriptors_filepath (MbimDevice *self)
     if (!device) {
         device = g_udev_client_query_by_subsystem_and_name (client, "usbmisc", device_basename);
         if (!device) {
-            g_warning ("[%s] Couldn't find udev device",
-                       self->priv->path_display);
+            /* possibly using a different driver instead of cdc_mbim */
+            g_debug ("[%s] Couldn't find udev device in usb/usbmisc subsystems",
+                     self->priv->path_display);
             goto out;
         }
     }
@@ -930,7 +933,7 @@ get_descriptors_filepath (MbimDevice *self)
         tmp = g_strdup_printf ("/sys/class/%s/%s/device", subsystems[i], device_basename);
         path = realpath (tmp, NULL);
 
-        if (g_file_test (path, G_FILE_TEST_EXISTS)) {
+        if (path && g_file_test (path, G_FILE_TEST_EXISTS)) {
             /* Now look for the parent dir with descriptors file. */
             g_autofree gchar *dirname = NULL;
 
@@ -964,8 +967,13 @@ read_max_control_transfer (MbimDevice *self)
     /* Build descriptors filepath */
     descriptors_path = get_descriptors_filepath (self);
     if (!descriptors_path) {
-        g_warning ("[%s] Couldn't get descriptors file path",
-                   self->priv->path_display);
+        /* If descriptors file doesn't exist, it's probably because we're using
+         * some other kernel driver, not the cdc_wdm/cdc_mbim pair, so fallback to
+         * the default and avoid warning about it. */
+        g_debug ("[%s] Couldn't find descriptors file, possibly not using cdc_mbim",
+                 self->priv->path_display);
+        g_debug ("[%s] Fallback to default max control message size: %u",
+                 self->priv->path_display, MAX_CONTROL_TRANSFER);
         return MAX_CONTROL_TRANSFER;
     }
 
