@@ -26,6 +26,7 @@
 #include "mbim-proxy-helpers.h"
 #include "mbim-message-private.h"
 #include "mbim-message.h"
+#include "mbim-error-types.h"
 #include "mbim-cid.h"
 #include "mbim-uuid.h"
 
@@ -130,45 +131,69 @@ _mbim_proxy_helper_service_subscribe_list_debug (const MbimEventEntry * const *l
 /*****************************************************************************/
 
 MbimEventEntry **
-_mbim_proxy_helper_service_subscribe_request_parse (MbimMessage *message,
-                                                    gsize       *out_size)
+_mbim_proxy_helper_service_subscribe_request_parse (MbimMessage  *message,
+                                                    gsize        *out_size,
+                                                    GError      **error)
 {
     MbimEventEntry **array = NULL;
     guint32 i;
     guint32 element_count;
     guint32 offset = 0;
     guint32 array_offset;
-    MbimEventEntry *event;
+    GError *inner_error = NULL;
 
     g_assert (message != NULL);
     g_assert (out_size != NULL);
 
-    element_count = _mbim_message_read_guint32 (message, offset);
+    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND) {
+        g_set_error (error,
+                     MBIM_CORE_ERROR,
+                     MBIM_CORE_ERROR_INVALID_MESSAGE,
+                     "Message is not a request");
+        return FALSE;
+    }
+
+    if (!mbim_message_command_get_raw_information_buffer (message, NULL)) {
+        g_set_error (error,
+                     MBIM_CORE_ERROR,
+                     MBIM_CORE_ERROR_INVALID_MESSAGE,
+                     "Message does not have information buffer");
+        return FALSE;
+    }
+
+    if (!_mbim_message_read_guint32 (message, offset, &element_count, error))
+        return NULL;
+
     if (element_count) {
-        array = g_new (MbimEventEntry *, element_count + 1);
+        array = g_new0 (MbimEventEntry *, element_count + 1);
 
         offset += 4;
         for (i = 0; i < element_count; i++) {
-            array_offset = _mbim_message_read_guint32 (message, offset);
+            const MbimUuid *uuid;
 
-            event = g_new (MbimEventEntry, 1);
+            if (!_mbim_message_read_guint32 (message, offset, &array_offset, &inner_error))
+                break;
+            if (!_mbim_message_read_uuid (message, array_offset, &uuid, &inner_error))
+                break;
 
-            memcpy (&(event->device_service_id), _mbim_message_read_uuid (message, array_offset), 16);
+            array[i] = g_new0 (MbimEventEntry, 1);
+            memcpy (&(array[i]->device_service_id), uuid, 16);
             array_offset += 16;
 
-            event->cids_count = _mbim_message_read_guint32 (message, array_offset);
+            if (!_mbim_message_read_guint32 (message, array_offset, &(array[i])->cids_count, &inner_error))
+                break;
             array_offset += 4;
 
-            if (event->cids_count)
-                event->cids = _mbim_message_read_guint32_array (message, event->cids_count, array_offset);
-            else
-                event->cids = NULL;
-
-            array[i] = event;
+            if (array[i]->cids_count && !_mbim_message_read_guint32_array (message, array[i]->cids_count, array_offset, &array[i]->cids, &inner_error))
+                break;
             offset += 8;
         }
+    }
 
-        array[element_count] = NULL;
+    if (inner_error) {
+        mbim_event_entry_array_free (array);
+        g_propagate_error (error, inner_error);
+        return NULL;
     }
 
     *out_size = element_count;
