@@ -976,8 +976,12 @@ process_command (MbimProxy   *self,
     /* create request holder */
     request = request_new (self, client, message);
 
-    /* replace command transaction id with internal proxy transaction id to avoid collision */
-    mbim_message_set_transaction_id (message, mbim_device_get_next_transaction_id (client->device));
+    if (_mbim_message_fragment_get_current (message) == _mbim_message_fragment_get_total (message) - 1)
+        /* replace command transaction id with internal proxy transaction id to avoid collision */
+        mbim_message_set_transaction_id (message, mbim_device_get_next_transaction_id (client->device));
+    else
+        /* avoid incrementing transaction until the last fragment is processed */
+        mbim_message_set_transaction_id (message, mbim_device_get_transaction_id (client->device));
 
     /* The timeout needs to be big enough for any kind of transaction to
      * complete, otherwise the remote clients will lose the reply if they
@@ -1121,7 +1125,6 @@ incoming_cb (GSocketService    *service,
     credentials = g_socket_get_credentials (g_socket_connection_get_socket (connection), &error);
     if (!credentials) {
         g_warning ("Client not allowed: Error getting socket credentials: %s", error->message);
-        g_error_free (error);
         return;
     }
 
@@ -1293,11 +1296,12 @@ merge_client_service_subscribe_lists (MbimProxy  *self,
 
     if (mbim_utils_get_traces_enabled ()) {
         g_debug ("Merged service subscribe list built for device '%s'", mbim_device_get_path (device));
-        _mbim_proxy_helper_service_subscribe_list_debug ((const MbimEventEntry * const *)updated, updated_size);
+        _mbim_proxy_helper_service_subscribe_list_debug ((const MbimEventEntry * const *)ctx->mbim_event_entry_array,
+                                                         ctx->mbim_event_entry_array_size);
     }
 
-    *out_size = updated_size;
-    return updated;
+    *out_size = ctx->mbim_event_entry_array_size;
+    return ctx->mbim_event_entry_array;
 }
 
 static void
@@ -1367,12 +1371,9 @@ static void
 untrack_device (MbimProxy  *self,
                 MbimDevice *device)
 {
-    GList         *l;
-    GList         *to_remove = NULL;
-    DeviceContext *ctx;
+    GList *l;
+    GList *to_remove = NULL;
 
-    ctx = device_context_get (device);
-    g_assert (ctx);
 
     if (!g_list_find (self->priv->devices, device))
         return;
