@@ -32,12 +32,22 @@
 
 G_BEGIN_DECLS
 
+/**
+ * SECTION: mbim-uuid
+ * @title: UUIDs
+ * @short_description: Generic UUID handling routines.
+ *
+ * This section defines the data type for unique identifiers.
+ */
+
 /*****************************************************************************/
 
 /**
  * MbimUuid:
  *
  * A UUID as defined in MBIM.
+ *
+ * Since: 1.0
  */
 typedef struct _MbimUuid MbimUuid;
 #define MBIM_PACKED __attribute__((__packed__))
@@ -50,11 +60,48 @@ struct MBIM_PACKED _MbimUuid {
 };
 #undef MBIM_PACKED
 
-gboolean  mbim_uuid_cmp            (const MbimUuid *a,
-                                    const MbimUuid *b);
-gchar    *mbim_uuid_get_printable  (const MbimUuid *uuid);
-gboolean  mbim_uuid_from_printable (const gchar *str,
-                                    MbimUuid    *uuid);
+/**
+ * mbim_uuid_cmp:
+ * @a: a #MbimUuid.
+ * @b: a #MbimUuid.
+ *
+ * Compare two %MbimUuid values.
+ *
+ * Returns: %TRUE if @a and @b are equal, %FALSE otherwise.
+ *
+ * Since: 1.0
+ */
+gboolean  mbim_uuid_cmp (const MbimUuid *a,
+                         const MbimUuid *b);
+
+/**
+ * mbim_uuid_get_printable:
+ * @uuid: a #MbimUuid.
+ *
+ * Get a string with the UUID.
+ *
+ * Returns: (transfer full): a newly allocated string, which should be freed with g_free().
+ *
+ * Since: 1.0
+ */
+gchar *mbim_uuid_get_printable (const MbimUuid *uuid);
+
+/**
+ * mbim_uuid_from_printable:
+ * @str: a MBIM UUID.
+ * @uuid: pointer to the target #MbimUuid.
+ *
+ * Fills in @uuid from the printable representation give in @str.
+ *
+ * Only ccepts @str written with dashes separating items, e.g.:
+ *  a289cc33-bcbb-8b4f-b6b0-133ec2aae6df
+ *
+ * Returns: %TRUE if @uuid was correctly set, %FALSE otherwise.
+ *
+ * Since: 1.8
+ */
+gboolean mbim_uuid_from_printable (const gchar *str,
+                                   MbimUuid    *uuid);
 
 /*****************************************************************************/
 
@@ -68,18 +115,20 @@ gboolean  mbim_uuid_from_printable (const gchar *str,
  * @MBIM_SERVICE_STK: SIM toolkit service.
  * @MBIM_SERVICE_AUTH: Authentication service.
  * @MBIM_SERVICE_DSS: Device Service Stream service.
- * @MBIM_SERVICE_MS_FIRMWARE_ID: Microsoft Firmware ID service.
- * @MBIM_SERVICE_MS_HOST_SHUTDOWN: Microsoft Host Shutdown service.
- * @MBIM_SERVICE_PROXY_CONTROL: Proxy Control service.
- * @MBIM_SERVICE_QMI: QMI-over-MBIM service.
- * @MBIM_SERVICE_ATDS: ATT Device service.
- * @MBIM_SERVICE_INTEL_FIRMWARE_UPDATE: Intel firmware update service.
- * @MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS: Microsoft basic connectivity extensions service.
+ * @MBIM_SERVICE_MS_FIRMWARE_ID: Microsoft Firmware ID service. Since 1.8.
+ * @MBIM_SERVICE_MS_HOST_SHUTDOWN: Microsoft Host Shutdown service. Since 1.8.
+ * @MBIM_SERVICE_PROXY_CONTROL: Proxy Control service. Since 1.10.
+ * @MBIM_SERVICE_QMI: QMI-over-MBIM service. Since 1.14.
+ * @MBIM_SERVICE_ATDS: ATT Device service. Since 1.16.
+ * @MBIM_SERVICE_INTEL_FIRMWARE_UPDATE: Intel firmware update service. Since 1.16.
+ * @MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS: Microsoft basic connectivity extensions service. Since 1.18.
  * @MBIM_SERVICE_LAST: Internal value.
  *
  * Enumeration of the generic MBIM services.
+ *
+ * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     MBIM_SERVICE_INVALID                     = 0,
     MBIM_SERVICE_BASIC_CONNECT               = 1,
     MBIM_SERVICE_SMS                         = 2,
@@ -106,6 +155,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_INVALID service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_INVALID mbim_uuid_from_service (MBIM_SERVICE_INVALID)
 
@@ -115,6 +166,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_BASIC_CONNECT service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_BASIC_CONNECT mbim_uuid_from_service (MBIM_SERVICE_BASIC_CONNECT)
 
@@ -124,6 +177,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_SMS service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_SMS mbim_uuid_from_service (MBIM_SERVICE_SMS)
 
@@ -133,6 +188,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_USSD service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_USSD mbim_uuid_from_service (MBIM_SERVICE_USSD)
 
@@ -142,6 +199,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_PHONEBOOK service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_PHONEBOOK mbim_uuid_from_service (MBIM_SERVICE_PHONEBOOK)
 
@@ -151,6 +210,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_STK service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_STK mbim_uuid_from_service (MBIM_SERVICE_STK)
 
@@ -160,6 +221,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_AUTH service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_AUTH mbim_uuid_from_service (MBIM_SERVICE_AUTH)
 
@@ -169,6 +232,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_DSS service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
  */
 #define MBIM_UUID_DSS mbim_uuid_from_service (MBIM_SERVICE_DSS)
 
@@ -178,6 +243,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_MS_FIRMWARE_ID service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.8
  */
 #define MBIM_UUID_MS_FIRMWARE_ID mbim_uuid_from_service (MBIM_SERVICE_MS_FIRMWARE_ID)
 
@@ -187,6 +254,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_MS_HOST_SHUTDOWN service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.8
  */
 #define MBIM_UUID_MS_HOST_SHUTDOWN mbim_uuid_from_service (MBIM_SERVICE_MS_HOST_SHUTDOWN)
 
@@ -196,6 +265,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_PROXY_CONTROL service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.10
  */
 #define MBIM_UUID_PROXY_CONTROL mbim_uuid_from_service (MBIM_SERVICE_PROXY_CONTROL)
 
@@ -205,6 +276,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_QMI service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.14
  */
 #define MBIM_UUID_QMI mbim_uuid_from_service (MBIM_SERVICE_QMI)
 
@@ -214,6 +287,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_ATDS service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.16
  */
 #define MBIM_UUID_ATDS mbim_uuid_from_service (MBIM_SERVICE_ATDS)
 
@@ -223,6 +298,8 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_INTEL_FIRMWARE_UPDATE service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.16
  */
 #define MBIM_UUID_INTEL_FIRMWARE_UPDATE mbim_uuid_from_service (MBIM_SERVICE_INTEL_FIRMWARE_UPDATE)
 
@@ -232,21 +309,90 @@ typedef enum {
  * Get the UUID of the %MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS service.
  *
  * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.18
  */
 #define MBIM_UUID_MS_BASIC_CONNECT_EXTENSIONS mbim_uuid_from_service (MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS)
 
+/**
+ * mbim_service_lookup_name:
+ * @service: a MbimService or custom service.
+ *
+ * Gets the nickname string for the @service.
+ *
+ * As opposed to mbim_service_get_string(), this methods takes into account
+ * custom services that may have been registered by the user.
+ *
+ * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
+ *
+ * Since: 1.10
+ */
 const gchar *mbim_service_lookup_name (guint service);
 
+/**
+ * mbim_register_custom_service:
+ * @uuid: MbimUuid structure corresponding to service
+ * @nickname: a printable name for service
+ *
+ * Register a custom service
+ *
+ * Returns: TRUE if service has been registered, FALSE otherwise.
+ *
+ * Since: 1.10
+ */
 guint mbim_register_custom_service (const MbimUuid *uuid,
-                                    const gchar *nickname);
+                                    const gchar    *nickname);
 
+/**
+ * mbim_unregister_custom_service:
+ * @id: ID of the service to unregister.MbimUuid structure corresponding to service
+ *
+ * Unregister a custom service.
+ *
+ * Returns: TRUE if service has been unregistered, FALSE otherwise.
+ *
+ * Since: 1.10
+ */
 gboolean mbim_unregister_custom_service (const guint id);
 
+/**
+ * mbim_service_id_is_custom:
+ * @id: ID of the service
+ *
+ * Checks whether @id is a custom or standard service.
+ *
+ * Returns: TRUE if service is custom, FALSE otherwise.
+ *
+ * Since: 1.10
+ */
 gboolean mbim_service_id_is_custom (const guint id);
 
-/* To/From service */
-const MbimUuid *mbim_uuid_from_service  (MbimService     service);
-MbimService     mbim_uuid_to_service    (const MbimUuid *uuid);
+/**
+ * mbim_uuid_from_service:
+ * @service: a #MbimService.
+ *
+ * Get the UUID corresponding to @service.
+ *
+ * The @service needs to be either a generic one (including #MBIM_SERVICE_INVALID)
+ * or a custom registered one.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
+ */
+const MbimUuid *mbim_uuid_from_service (MbimService service);
+
+/**
+ * mbim_uuid_to_service:
+ * @uuid: a #MbimUuid.
+ *
+ * Get the service corresponding to @uuid.
+ *
+ * Returns: a #MbimService.
+ *
+ * Since: 1.0
+ */
+MbimService mbim_uuid_to_service (const MbimUuid *uuid);
 
 /*****************************************************************************/
 
@@ -264,8 +410,10 @@ MbimService     mbim_uuid_to_service    (const MbimUuid *uuid);
  * @MBIM_CONTEXT_TYPE_LOCAL: A local.
  *
  * Enumeration of the generic MBIM context types.
+ *
+ * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     MBIM_CONTEXT_TYPE_INVALID     = 0,
     MBIM_CONTEXT_TYPE_NONE        = 1,
     MBIM_CONTEXT_TYPE_INTERNET    = 2,
@@ -278,9 +426,29 @@ typedef enum {
     MBIM_CONTEXT_TYPE_LOCAL       = 9,
 } MbimContextType;
 
-/* To/From context type */
-const MbimUuid  *mbim_uuid_from_context_type (MbimContextType  context_type);
-MbimContextType  mbim_uuid_to_context_type   (const MbimUuid  *uuid);
+/**
+ * mbim_uuid_from_context_type:
+ * @context_type: a #MbimContextType.
+ *
+ * Get the UUID corresponding to @context_type.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.0
+ */
+const MbimUuid *mbim_uuid_from_context_type (MbimContextType context_type);
+
+/**
+ * mbim_uuid_to_context_type:
+ * @uuid: a #MbimUuid.
+ *
+ * Get the context type corresponding to @uuid.
+ *
+ * Returns: a #MbimContextType.
+ *
+ * Since: 1.0
+ */
+MbimContextType mbim_uuid_to_context_type (const MbimUuid *uuid);
 
 G_END_DECLS
 
